# Terminis
Tetris clone for terminal. Ideal for servers without GUI!

## Installation

```bash
pip install --user terminis
```

## Usage

```bash
terminis [edit|help|n]
```
* edit: edit controls in text editor
* help: show command usage
* n (integer between 1 and 15): start at level n
